@@ -19,13 +19,13 @@
 --
 -- > page1 :: Html
 -- > page1 = html $ do
--- > 	head $ do
--- > 		title "Introduction page."
--- > 		link ! rel "stylesheet" ! type_ "text/css" ! href "screen.css"
--- > 	body $ do
--- > 		div ! id "header" $ "Syntax"
--- > 		p "This is an example of BlazeHtml syntax."
--- > 		ul $ forM_ [1, 2, 3] (li . string . show)
+-- >     head $ do
+-- >         title "Introduction page."
+-- >         link ! rel "stylesheet" ! type_ "text/css" ! href "screen.css"
+-- >     body $ do
+-- >         div ! id "header" $ "Syntax"
+-- >         p "This is an example of BlazeHtml syntax."
+-- >         ul $ mapM_ (li . toHtml . show) [1, 2, 3]
 --
 -- The resulting HTML can now be extracted using:
 --
@@ -73,6 +73,8 @@ module Text.Blaze
     , (!)
     ) where
 
+import Data.Monoid (mconcat)
+
 import Data.Text (Text)
 import qualified Data.Text.Lazy as LT
 
@@ -89,6 +91,10 @@ instance ToHtml Html where
     toHtml = id
     {-# INLINE toHtml #-}
 
+instance ToHtml [Html] where
+    toHtml = mconcat
+    {-# INLINE toHtml #-}
+
 instance ToHtml Text where
     toHtml = text
     {-# INLINE toHtml #-}
